Index: gm/rebaseline_server/compare_configs_test.py |
diff --git a/gm/rebaseline_server/compare_to_expectations_test.py b/gm/rebaseline_server/compare_configs_test.py |
similarity index 73% |
copy from gm/rebaseline_server/compare_to_expectations_test.py |
copy to gm/rebaseline_server/compare_configs_test.py |
index c0bf19003f6c86f0ad0bf9bf3feeb02fdc3b0453..756af6615649506c414c016d87a5e61c955d1c78 100755 |
--- a/gm/rebaseline_server/compare_to_expectations_test.py |
+++ b/gm/rebaseline_server/compare_configs_test.py |
@@ -1,12 +1,12 @@ |
#!/usr/bin/python |
""" |
-Copyright 2013 Google Inc. |
+Copyright 2014 Google Inc. |
Use of this source code is governed by a BSD-style license that can be |
found in the LICENSE file. |
-Test compare_to_expectations.py |
+Test compare_configs.py |
TODO(epoger): Create a command to update the expected results (in |
self._output_dir_expected) when appropriate. For now, you should: |
@@ -23,18 +23,18 @@ import sys |
# Imports from within Skia |
import base_unittest |
-import compare_to_expectations |
+import compare_configs |
import results |
import gm_json # must import results first, so that gm_json will be in sys.path |
-class CompareToExpectationsTest(base_unittest.TestCase): |
+class CompareConfigsTest(base_unittest.TestCase): |
def test_gm(self): |
- """Process results of a GM run with the Results object.""" |
- results_obj = compare_to_expectations.Results( |
+ """Process results of a GM run with the ConfigComparisons object.""" |
+ results_obj = compare_configs.ConfigComparisons( |
+ configs=('8888', 'gpu'), |
actuals_root=os.path.join(self._input_dir, 'gm-actuals'), |
- expected_root=os.path.join(self._input_dir, 'gm-expectations'), |
generated_images_root=self._temp_dir, |
diff_base_url='/static/generated-images') |
results_obj.get_timestamp = mock_get_timestamp |
@@ -45,12 +45,12 @@ class CompareToExpectationsTest(base_unittest.TestCase): |
def mock_get_timestamp(): |
"""Mock version of Results.get_timestamp() for testing.""" |
return 12345678 |
def main(): |
- base_unittest.main(CompareToExpectationsTest) |
+ base_unittest.main(CompareConfigsTest) |
if __name__ == '__main__': |
@@ -45,12 +45,12 @@ class CompareToExpectationsTest(base_unittest.TestCase): |
def mock_get_timestamp(): |
- """Mock version of Results.get_timestamp() for testing.""" |
+ """Mock version of BaseComparisons.get_timestamp() for testing.""" |
return 12345678 |
def main(): |